@@ -1,13 +1,13 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
     generate portrait landscape
     north east south west
-    layout checkerboard
+    layout checkerboard animate
     chess checkers conway
     calculator dk shroom
 );
@@ -32,6 +32,7 @@ sub calculator      { Spreadsheet::HTML::Presets::calculator( @_ ) }
 sub chess           { Spreadsheet::HTML::Presets::chess( @_ ) }
 sub checkers        { Spreadsheet::HTML::Presets::checkers( @_ ) }
 sub checkerboard    { Spreadsheet::HTML::Presets::checkerboard( @_ ) }
+sub animate         { Spreadsheet::HTML::Presets::animate( @_ ) }
 sub dk              { Spreadsheet::HTML::Presets::dk( @_ ) }
 sub shroom          { Spreadsheet::HTML::Presets::shroom( @_ ) }
 
@@ -355,7 +356,7 @@ generating methods below:
 =item * C<north( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #505050"><td>heading1</th><td>heading2</th><td>heading3</th></tr><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr></table>
+<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #505050"><td>heading1</td><td>heading2</td><td>heading3</td></tr><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr></table>
 
   $html = $table->generate( table => {border => 1}, encode => '<>' );
   print Spreadsheet::HTML::generate( data => $data, indent => "\t" );
@@ -370,7 +371,7 @@ calls C<generate> like so:
 =item * C<west( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td style="color: #505050">heading1</th><td>row1col1</td><td>row2col1</td><td>row3col1</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading2</th><td>row1col2</td><td>row2col2</td><td>row3col2</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading3</th><td>row1col3</td><td>row2col3</td><td>row3col3</td></tr></table>
+<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td style="color: #505050">heading1</td><td>row1col1</td><td>row2col1</td><td>row3col1</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading2</td><td>row1col2</td><td>row2col2</td><td>row3col2</td></tr><tr style="color: #A0A0A0"><td style="color: #505050">heading3</td><td>row1col3</td><td>row2col3</td><td>row3col3</td></tr></table>
 
 Headers on left. C<west()> is an alias for C<landscape()> which
 in turn calls C<generate> like so:
@@ -380,7 +381,7 @@ in turn calls C<generate> like so:
 =item * C<south( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr><tr style="color: #505050"><td>heading1</th><td>heading2</th><td>heading3</th></tr></table>
+<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row1col2</td><td>row1col3</td></tr><tr style="color: #A0A0A0"><td>row2col1</td><td>row2col2</td><td>row2col3</td></tr><tr style="color: #A0A0A0"><td>row3col1</td><td>row3col2</td><td>row3col3</td></tr><tr style="color: #505050"><td>heading1</td><td>heading2</td><td>heading3</td></tr></table>
 
 Headers on bottom. Same as
 
@@ -389,7 +390,7 @@ Headers on bottom. Same as
 =item * C<east( %params )>
 
 =for html
-<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row2col1</td><td>row3col1</td><td style="color: #505050">heading1</th></tr><tr style="color: #A0A0A0"><td>row1col2</td><td>row2col2</td><td>row3col2</td><td style="color: #505050">heading2</th></tr><tr style="color: #A0A0A0"><td>row1col3</td><td>row2col3</td><td>row3col3</td><td style="color: #505050">heading3</th></tr></table>
+<table cellspacing="10" style="border: 1px dashed #A0A0A0"><tr style="color: #A0A0A0"><td>row1col1</td><td>row2col1</td><td>row3col1</td><td style="color: #505050">heading1</td></tr><tr style="color: #A0A0A0"><td>row1col2</td><td>row2col2</td><td>row3col2</td><td style="color: #505050">heading2</td></tr><tr style="color: #A0A0A0"><td>row1col3</td><td>row2col3</td><td>row3col3</td><td style="color: #505050">heading3</td></tr></table>
 
 Headers on right. Same as
 
@@ -419,6 +420,8 @@ with little to no additional coding.
 
 =item * C<checkerboard( colors, %params )>
 
+=item * C<animate( direction, %params )>
+
 =item * C<chess( %params )>
 
 =item * C<checkers( %params )>
