@@ -3,6 +3,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use Spreadsheet::HTML;
+use Spreadsheet::HTML::Presets::Animate;
 use Spreadsheet::HTML::Presets::Conway;
 use Spreadsheet::HTML::Presets::Calculator;
 
@@ -52,6 +53,38 @@ sub checkerboard {
     $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
 
+sub animate {
+    my ($self,$data,$args);
+    $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
+    ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
+
+    $args->{direction} ||= 'right';
+    $args->{interval}  ||= 200;
+
+    my @cells;
+    for my $r ( 0 .. $args->{_max_rows} - 1 ) {
+        for my $c ( 0 .. $args->{_max_cols} - 1 ) {
+            my $cell = sprintf '-row%scol%s', $r, $c;
+            push @cells, $cell => {
+                id     => join( '-', $r, $c ),
+                class  => 'animate',
+            };
+        }
+    }
+
+    my @args = (
+        @cells,
+        caption  => { '<button id="toggle" onClick="toggle()">Start</button>' => { align => 'bottom' } },
+        @_,
+    );
+
+    my $js = Spreadsheet::HTML::Presets::Animate::_javascript( %$args );
+    delete $args->{$_} for qw( direction x y interval jquery );
+
+    my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
+    return $js . $table;
+}
+
 sub calculator {
     my ($self,$data,$args);
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
@@ -122,6 +155,8 @@ sub conway {
         ? [ ($args->{on}) x 10 ]
         : [ Color::Spectrum::generate( 10, $args->{on}, $args->{off} ) ];
 
+    $args->{interval} ||= 200;
+
     my @cells;
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
@@ -139,12 +174,12 @@ sub conway {
 
     my @args = (
         @cells,
-        caption  => { '<button onClick="start()">Step</button>' => { align => 'bottom' } },
+        caption  => { '<button id="toggle" onClick="toggle()">Start</button>' => { align => 'bottom' } },
         @_,
     );
 
     my $js = Spreadsheet::HTML::Presets::Conway::_javascript( %$args );
-    delete $args->{$_} for qw( jquery off on colors fade );
+    delete $args->{$_} for qw( jquery off on colors fade interval );
 
     my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
     return $js . $table;
@@ -413,6 +448,90 @@ Instead, use the Spreadsheet::HTML interface:
   use Spreadsheet::HTML qw( layout );
   print layout( data => [[1],[2]] );
 
+=head1 METHODS
+
+=over 4
+
+=item * C<layout( %params )>
+
+Layout tables are not recommended, but if you choose to
+use them you should label them as such. This adds W3C
+recommended layout attributes to the table tag and features:
+emit only <td> tags, no padding or pruning of rows, forces
+no HTML entity encoding in table cells.
+
+=item * C<checkerboard( colors, %params )>
+
+Preset for tables with checkerboard colors.
+
+  checkerboard( colors => [qw(yellow orange)], extra => 'blue' )
+
+Attempts to form diagonal patterns by adding an extra color
+if need be. C<colors> default to red and green and C<extra>
+defaults to white.
+
+=item * C<animate( direction, interval, jquery, %params )>
+
+Moves the contents of each cell in the direction specified.
+Valid values are C<up>, C<down>, C<left> and C<right>.
+
+Set the timer with C<interval> (defaults to 200 miliseconds).
+
+  animate( direction => 'right', interval => 300 )
+
+Can optionally use C<x> and/or C<y> instead of C<direction>
+to specify which axis(es) to animate.
+
+Uses Google's jQuery API unless you specify another URI via
+the C<jquery> param. Javascript will be minified
+via L<Javascript::Minifier> if it is installed.
+
+=item * C<conway( on, off, fade, interval, jquery, %params )>
+
+Game of life. From an implementation i wrote back in college.
+
+  conway( on => 'red', off => 'gray' )
+
+Set the timer with C<interval> (defaults to 200 miliseconds).
+
+  conway( interval => 75 )
+
+If you have L<Color::Spectrum> installed (and optionally
+L<Color::Library>) then you can turn fade on for more
+effects:
+
+  # without Color::Library
+  conway( on => '#FF0000', off => '#999999', fade => 1 )
+
+  # with Color::Library
+  conway( on => 'red', off => 'gray', fade => 1 )
+
+Uses Google's jQuery API unless you specify another URI via
+the C<jquery> param. Javascript will be minified
+via L<Javascript::Minifier> if it is installed.
+
+=item * C<calculator( jquery )>
+
+Generates a simple calculator.
+
+Uses Google's jQuery API unless you specify another URI via
+the C<jquery> param. Javascript will be minified
+via L<Javascript::Minifier> if it is installed.
+
+=item * C<checkers( %params )>
+
+Generates a static checkers game board (US).
+
+=item * C<chess( %params )>
+
+Generates a static chess game board.
+
+=item * C<dk( %params )>
+
+=item * C<shroom( %params )>
+
+=back
+
 =head1 CUSTOMIZATION
 
 You can use the methods in this package as an example for
@@ -464,70 +583,6 @@ pull out client params:
 Plans are in the works to simplify this "API," possibly even
 to provide a real plugin interface.
 
-=head1 METHODS
-
-=over 4
-
-=item * C<layout( %params )>
-
-Layout tables are not recommended, but if you choose to
-use them you should label them as such. This adds W3C
-recommended layout attributes to the table tag and features:
-emit only <td> tags, no padding or pruning of rows, forces
-no HTML entity encoding in table cells.
-
-=item * C<checkerboard( colors, %params )>
-
-Preset for tables with checkerboard colors.
-
-  checkerboard( colors => [qw(yellow orange)], extra => 'blue' )
-
-Attempts to form diagonal patterns by adding an extra color
-if need be. C<colors> default to red and green and C<extra>
-defaults to white.
-
-=item * C<conway( on, off, fade, jquery, %params )>
-
-Game of life. From an implementation i wrote back in college.
-
-  conway( on => 'red', off => 'gray' )
-
-If you have L<Color::Spectrum> installed (and optionally
-L<Color::Library>) then you can turn fade on for more
-effects:
-
-  # without Color::Library
-  conway( on => '#FF0000', off => '#999999', fade => 1 )
-
-  # with Color::Library
-  conway( on => 'red', off => 'gray', fade => 1 )
-
-Uses Google's jQuery API unless you specify another URI via
-the C<jquery> param. Javascript will be minified
-via L<Javascript::Minifier> if it is installed.
-
-=item * C<calculator( jquery )>
-
-Generates a simple calculator.
-
-Uses Google's jQuery API unless you specify another URI via
-the C<jquery> param. Javascript will be minified
-via L<Javascript::Minifier> if it is installed.
-
-=item * C<checkers( %params )>
-
-Generates a static checkers game board (US).
-
-=item * C<chess( %params )>
-
-Generates a static chess game board.
-
-=item * C<dk( %params )>
-
-=item * C<shroom( %params )>
-
-=back
-
 =head1 AUTHOR
 
 Jeff Anderson, C<< <jeffa at cpan.org> >>
